@@ -1,6 +1,6 @@
 #!/usr/bin/perl -w -T
 #
-# $Header: /home/LDMS/cvsroot/LDMS/LDMS.pl,v 1.38 2000/12/01 02:13:45 jcl53 Exp $
+# $Header: /home/LDMS/cvsroot/LDMS/LDMS.pl,v 1.39 2000/12/01 20:34:53 jcl53 Exp $
 
 
 #==============================================================================
@@ -103,16 +103,23 @@ if (scalar(@ARGV) > 0) {  # Show help if there's still junk at command line.
 if ($opt_output ne "") {  # If passed an output filename, use that.
     $outputFilename = $opt_output;
 }
-else {  # Default output filename is input filename with .xml extension.
-    $outputFilename = $inputFilename;
+elsif ($inputFilename =~ /\.\w*$/) {  # Replace extension with .xml.
     $outputFilename =~ s/\.\w*$/\.xml/g;   
 }
+else {  # Default output filename is input filename with .xml appended.
+    $outputFilename = $inputFilename . ".xml";
+}
 
 
 ## If the output filename is a directory, slap '.xml' on input and write there.
 if (-d $outputFilename) {
     $outputFilename = catfile($outputFilename, &basename($inputFilename));
-    $outputFilename =~ s/\.\w*$/\.xml/g;
+    if ($outputFilename =~ /\.\w*$/) {  # Replace extension with ".xml"...
+	$outputFilename =~ s/\.\w*$/\.xml/g;
+    }
+    else {  # Or append ".xml" extension.
+	$outputFilename .= ".xml";
+    }
 }
 
 
@@ -802,6 +809,9 @@ __END__;
 
 
 $Log: LDMS.pl,v $
+Revision 1.39  2000/12/01 20:34:53  jcl53
+Handles input filenames with no extension correctly.
+
 Revision 1.38  2000/12/01 02:13:45  jcl53
 Removed the redundant debugging code that was producing duplicate status messages.
 
